==> haskell-netlink-1.1.1.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-1KzhkEp5z1rJERBCfOtdQQ
key:                  netlink-1.1.1.0-1KzhkEp5z1rJERBCfOtdQQ
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  2c936989d4c45d882f0da183c6099210
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-8.10.4/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/netlink-1.1.1.0
hs-libraries:         HSnetlink-1.1.1.0-1KzhkEp5z1rJERBCfOtdQQ
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc containers-0.6.2.1
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q
    pretty-hex-1.1-A9yHwnEXv1oK2wKeJxKmju unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-netlink-1.1.1.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-netlink.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 netlink
version:              1.1.1.0
visibility:           public
id:                   netlink-1.1.1.0-1sh2rjC98zV9n9qwh9hdFs
key:                  netlink-1.1.1.0-1sh2rjC98zV9n9qwh9hdFs
license:              BSD-3-Clause
copyright:            Google Inc. 2010
maintainer:           Markus Ongyerth <ongy@ongy.net>
author:               David Anderson
stability:            Alpha
homepage:             https://github.com/Ongy/netlink-hs
synopsis:             Netlink communication for Haskell
description:          Library to comminicate with Linux kernel via Netlink
category:             System
abi:                  19229b742c7942628620468480ed9f1c
exposed:              True
exposed-modules:
    System.Linux.Netlink System.Linux.Netlink.Constants
    System.Linux.Netlink.GeNetlink
    System.Linux.Netlink.GeNetlink.Constants
    System.Linux.Netlink.GeNetlink.Control
    System.Linux.Netlink.GeNetlink.NL80211
    System.Linux.Netlink.GeNetlink.NL80211.Constants
    System.Linux.Netlink.GeNetlink.NL80211.StaInfo
    System.Linux.Netlink.GeNetlink.NL80211.WifiEI
    System.Linux.Netlink.Helpers System.Linux.Netlink.Route
    System.Linux.Netlink.Route.LinkStat

hidden-modules:       System.Linux.Netlink.C
import-dirs:          /usr/lib/ghc-8.10.5/site-local/netlink-1.1.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/netlink-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/netlink-1.1.1.0
hs-libraries:         HSnetlink-1.1.1.0-1sh2rjC98zV9n9qwh9hdFs
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl containers-0.6.4.1
    monad-loops-0.4.3-8Lx5Hn3pTtO62yOPdPW77x
    pretty-hex-1.1-2i4ClvFN4Y7LxbHQYNmVC0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-netlink/html/netlink.haddock
haddock-html:         /usr/share/doc/haskell-netlink/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
